@@ -39,6 +39,10 @@ def silhouette_scores(df, n_clusters=20, max_iter=500, tol=1e-04, init="random",
     
 def plot_clusters(data,cluster_centers, n = 1):
     
+    import plotly.io as pio
+    import plotly.express as px
+    import plotly.graph_objects as go
+    
     pio.renderers.default='browser'
     centroides = pd.DataFrame(cluster_centers, columns=(data.columns))
     centroides = (centroides-centroides.min())/(centroides.max()-centroides.min())
