@@ -4,7 +4,7 @@ def get_stock_data(tickers, prices = False, financials = False,
     import pandas as pd
     import yfinance as yf
     
-    info = {}
+    information = {}
     tickers = [ticker.lower() for ticker in tickers]
     
     for ticker in tickers:
@@ -13,29 +13,29 @@ def get_stock_data(tickers, prices = False, financials = False,
             if prices == True:
                 stock = yf.Ticker(ticker)
                 stock = stock.history(period="max")
-                info[ticker] = stock
+                information[ticker] = stock
             
             if financials == True:
                 stock = yf.Ticker(ticker)
                 stock = stock.financials
-                info[ticker] = stock
+                information[ticker] = stock
                 
             if info == True:
                 stock = yf.Ticker(ticker)
                 stock = stock.info
                 stock = pd.DataFrame.from_dict(stock, orient = "index").T
-                info[ticker] = stock
+                information[ticker] = stock
             
             if recommendations == True:
                 stock = yf.Ticker(ticker)
                 stock = stock.recommendations
-                info[ticker] = stock
+                information[ticker] = stock
                 
             
             else:
                 pass
         except:
             pass
-    return info
+    return information
 
 
